@@ -2,7 +2,7 @@
 python -m nbcourse module entry point to run via python -m
 """
 
-from . import main
+from .main import main
 
 
 if __name__ == '__main__':
