@@ -110,16 +110,12 @@ No notebooks found!
             Path(self.conf['slug_title']).with_suffix('.zip')
 
         # Instantiate notebook exporter
-        self.html_exporter = HTMLExporter()
+        self.html_exporter = HTMLExporter(template_name='classic')
 
         # Instantiate slide exporter
         self.slide_exporter = SlidesExporter()
-        reveal_url = \
-            "https://cdnjs.cloudflare.com/ajax/libs/reveal.js/3.7.0"
         if self.conf['local_reveal']:
             self.slide_exporter.reveal_url_prefix = 'reveal.js'
-        else:
-            self.slide_exporter.reveal_url_prefix = reveal_url
 
     def _get_config(self, user_conf):
         """Get conf dict from default and user_conf"""
